==> am_mod_grp_0_1.tar.gz: am_mod_grp_0_1/components/grp/language/1/barnraiser_01/forum_subject.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADERS
$lang['hdr_tags'] = 							"tags";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_recommended'] = 						"recommended";
$lang['hdr_topic'] =							"topic";


// SUBMIT
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";
$lang['sub_update'] = 							"update discussion";
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";


//A HREF TAGS (links)
$lang['href_edit_page'] = 						"edit discussion";
$lang['href_respect'] = 						"respect";


// TEXT
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this page";
$lang['txt_alt_add_bookmark'] = 				"bookmark";
$lang['txt_title_add_bookmark'] = 				"bookmark this page";
$lang['txt_alt_add_track'] = 					"track";
$lang['txt_title_add_track'] = 					"track this page";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this page";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this page";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";
$lang['txt_manage_subject'] = 					"manage discussion";

$lang['txt_title_not_relevent'] = 				"you have voted this discussion as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this discussion is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this discussion as relevent";
$lang['txt_title_set_relevent'] = 				"this discussion is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this discussion as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this discussion is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this discussion as accurate";
$lang['txt_title_set_accurate'] = 				"this discussion is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this discussion is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this discussion is accurate";

$lang['txt_locked'] = 							"locked";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_vote_history'] = 					"vote history";
$lang['txt_subject_locked'] = 					"This discussion has been locked.";
$lang['txt_tags'] = 							"tags";

?>

==> am_mod_grp_0_3.tar.gz: am_mod_grp_0_3/components/grp/language/1/barnraiser_01/forum_subject.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/grp_common.inc.php');


// HEADERS
$lang['hdr_tags'] = 							"tags";
$lang['hdr_subject'] = 							"discussion";
$lang['hdr_recommended'] = 						"recommended";
$lang['hdr_topic'] =							"topic";


// SUBMIT
$lang['sub_tag_ok'] = 							"OK";
$lang['sub_tag_delete'] = 						"DEL";
$lang['sub_update'] = 							"update discussion";
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";


//A HREF TAGS (links)
$lang['href_edit_subject'] = 					"edit discussion";
$lang['href_respect'] = 						"respect";


// TEXT
$lang['txt_participate_first'] = 				"you need to participate in order to leave comments";
$lang['txt_alt_remove_bookmark'] = 				"remove bookmark";
$lang['txt_title_remove_bookmark'] = 			"remove bookmark from this page";
$lang['txt_alt_add_bookmark'] = 				"bookmark";
$lang['txt_title_add_bookmark'] = 				"bookmark this page";
$lang['txt_alt_add_track'] = 					"track";
$lang['txt_title_add_track'] = 					"track this page";
$lang['txt_alt_remove_recommendation'] = 		"remove recommendation";
$lang['txt_title_remove_recommendation'] = 		"remove recommendation from this page";
$lang['txt_alt_add_recommendation'] = 			"recommend";
$lang['txt_title_add_recommendation'] = 		"recommend this page";
$lang['txt_relevent'] = 						"relevent?";
$lang['txt_accurate'] = 						"accurate?";
$lang['txt_manage_subject'] = 					"manage discussion";

$lang['txt_title_not_relevent'] = 				"you have voted this discussion as not relevent";
$lang['txt_title_set_not_relevent'] = 			"this discussion is not relevent";
$lang['txt_alt_not_relevent'] = 				"not relevent";
$lang['txt_title_relevent'] = 					"you have voted this discussion as relevent";
$lang['txt_title_set_relevent'] = 				"this discussion is relevent";
$lang['txt_alt_relevent'] = 					"relevent";

$lang['txt_title_not_accurate'] = 				"you have voted this discussion as not accurate";
$lang['txt_title_set_not_accurate'] = 			"this discussion is not accurate";
$lang['txt_alt_not_accurate'] = 				"not accurate";
$lang['txt_title_accurate'] = 					"you have voted this discussion as accurate";
$lang['txt_title_set_accurate'] = 				"this discussion is accurate";
$lang['txt_alt_accurate'] = 					"accurate";

$lang['txt_relevent_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this discussion is relevent";
$lang['txt_accurate_summary'] = 				"SYS_KEYWORD_PERCENTAGE% of people who have voted think this discussion is accurate";

$lang['txt_locked'] = 							"locked";
$lang['txt_sticky'] = 							"sticky";
$lang['txt_vote_history'] = 					"vote history";
$lang['txt_subject_locked'] = 					"This discussion has been locked.";
$lang['txt_tags'] = 							"tags";
$lang['txt_view_topic'] =						"view topic";

?>
